Method: History::Entry#dir_fn

Defined in:
lib/abelard/history.rb

#dir_fnObject (readonly)

dir_fn is the path to the file relative to the feed directory git_fn is the path to the file relative to the git root path is the full path



41
42
43
# File 'lib/abelard/history.rb', line 41

def dir_fn
  @dir_fn
end